==> zydis-4.1.1-1-x86_64.pkg.tar.zst: usr/share/doc/Zydis/api/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Zydis", "index.html", [
    [ "Topics", "topics.html", "topics" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"DecoderData_8h.html",
"EncoderData_8h.html#ac7020fe8f9e88d874e8c9ca22613eb29",
"EnumISASet_8h.html#acd2efc3f0ffbc8c925087924f01644a4a652be1a145031b4c8b5b23e39d16bf8e",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202da003458fd758e3e22e5238b5b4cffc3ce",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202da24abe73edb0ad98d016dc05f0a217729",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202da45231c4ca74b8a15d6a8f8214f124933",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202da6828ced5c93415e8e81d0eb66967f48a",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202da8efea6e1d9340758ffab5a8b69539cf6",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202dab2600cb38a449b18e3ad09170d83fb4d",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202dad639aba5c6bbca3211a2e4224d4b082f",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202daf8fa2351958b42a9be9e369b54498cc9",
"EnumRegister_8h.html#a10b6c9a56ea3347c85d46d89d5807281abc5bab23303b1c695e2eef0fb72ee677",
"Register_8h.html#a2a3d01ce215524842c66f1674ffbfca1a3d1472ac677766003c20b0a8d2548b49",
"SharedData_8h.html#ad308afb7c9a229141a601a30770f5ad2aafe5ccf102b4b96179f8fd5fed00380d",
"dir_63c7c89c77e3a564e6bd62eef934ef82.html",
"structZydisDecodedInstructionRawEvex.html#a9d167ea54fe7c99a9ab894cd59bb70ac",
"structZydisFormatterContext__.html"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';

==> zydis-4.1.1-2-x86_64.pkg.tar.zst: usr/share/doc/Zydis/api/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Zydis", "index.html", [
    [ "Topics", "topics.html", "topics" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"DecoderData_8h.html",
"EncoderData_8h.html#ac7020fe8f9e88d874e8c9ca22613eb29",
"EnumISASet_8h.html#acd2efc3f0ffbc8c925087924f01644a4a652be1a145031b4c8b5b23e39d16bf8e",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202da003458fd758e3e22e5238b5b4cffc3ce",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202da24abe73edb0ad98d016dc05f0a217729",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202da45231c4ca74b8a15d6a8f8214f124933",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202da6828ced5c93415e8e81d0eb66967f48a",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202da8efea6e1d9340758ffab5a8b69539cf6",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202dab2600cb38a449b18e3ad09170d83fb4d",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202dad639aba5c6bbca3211a2e4224d4b082f",
"EnumMnemonic_8h.html#a8e72e9a67afaf7087eca5e3aac53202daf8fa2351958b42a9be9e369b54498cc9",
"EnumRegister_8h.html#a10b6c9a56ea3347c85d46d89d5807281abc5bab23303b1c695e2eef0fb72ee677",
"Register_8h.html#a2a3d01ce215524842c66f1674ffbfca1a3db6b4b01396eb4fe99169a7b249082e",
"SharedData_8h.html#ad308afb7c9a229141a601a30770f5ad2ab1324a0877b5955dab0b5972bc5baaf3",
"dir_d44c64559bbebec7f509842c48db8b23.html",
"structZydisDecodedInstructionRawEvex.html#ab5e8ad79c7b6e8e6218afbc1fbcc7ad1",
"structZydisFormatterContext__.html#a8d65f7b2a44b9e84c9f48de0fec26cef"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';
